@@ -8,7 +8,7 @@ __PACKAGE__->mk_accessors(qw(classes));
 sub report {
     my ($self) = @_;
 
-    my $name = $self->name() || 'main';
+    my $name = $self->name() || '';
     ( my $name_dotted = $name ) =~ s/\W+/./g;
 
     my $data = {
@@ -30,11 +30,10 @@ sub files {
     }
 
     my @ret;
-    foreach my $name ( sort keys %frag_classes ) {
+    foreach my $name ( keys %frag_classes ) {
         my $classes = $frag_classes{$name};
         my $file    = Devel::Cover::Report::Clover::PackageFile->new(
             {   name    => $name,
-                builder => $self->builder,
                 classes => [@$classes]
             }
         );
@@ -48,9 +47,24 @@ sub files {
 sub metrics {
     my ($self) = @_;
 
-    my $metrics = $self->SUPER::metrics();
-    $metrics->{files}   = scalar @{ $self->files };
-    $metrics->{classes} = scalar @{ $self->classes() };
+    my $s = $self->summarize();
+
+    my $metrics = {
+        files   => scalar @{ $self->files },
+        classes => scalar @{ $self->classes() },
+
+        elements            => $s->{total}->{total}        || 0,
+        coveredelements     => $s->{total}->{covered}      || 0,
+        statements          => $s->{statement}->{total}    || 0,
+        coveredstatements   => $s->{statement}->{covered}  || 0,
+        complexity          => 0,
+        loc                 => $self->loc(),
+        ncloc               => $self->ncloc(),
+        conditionals        => $s->{branch}->{total}       || 0,
+        coveredconditionals => $s->{branch}->{covered}     || 0,
+        methods             => $s->{subroutine}->{total}   || 0,
+        coveredmethods      => $s->{subroutine}->{covered} || 0,
+    };
 
     return $metrics;
 }
@@ -122,9 +136,23 @@ sub report {
 sub metrics {
     my ($self) = @_;
 
-    my $metrics = $self->SUPER::metrics();
-    $metrics->{classes} = scalar @{ $self->classes() };
-    return $metrics;
+    my $s = $self->summarize();
+
+    my $metrics = {
+        classes => scalar @{ $self->classes },
+
+        elements            => $s->{total}->{total}        || 0,
+        coveredelements     => $s->{total}->{covered}      || 0,
+        statements          => $s->{statement}->{total}    || 0,
+        coveredstatements   => $s->{statement}->{covered}  || 0,
+        complexity          => 0,
+        loc                 => $self->loc(),
+        ncloc               => $self->ncloc(),
+        conditionals        => $s->{branch}->{total}       || 0,
+        coveredconditionals => $s->{branch}->{covered}     || 0,
+        methods             => $s->{subroutine}->{total}   || 0,
+        coveredmethods      => $s->{subroutine}->{covered} || 0,
+    };
 }
 
 sub summarize {
